@@ -6,16 +6,11 @@ source /etc/stellarmate/reset-factory-common.sh
 # Perform common reset operations with stellarmate hostname
 perform_common_reset "stellarmate"
 
-# SM-170 specific operations
-
 cp /etc/stellarmate/kstars/config/* /home/stellarmate/.var/app/org.kde.kstars/config/
-
-rm -rf /home/stellarmate/.var/app/org.kde.kstars/data/kstars
-mkdir -p /home/stellarmate/.var/app/org.kde.kstars/data/kstars
 cp /etc/stellarmate/kstars/catalogs/* /home/stellarmate/.var/app/org.kde.kstars/data/kstars/
 
-# Reset Plasma settings
-cp -rf /etc/stellarmate/plasma/* /home/stellarmate/.config
+# SM-170 specific operations
+sed -i 's|^HIPSOfflinePath=.*|HIPSOfflinePath=/home/stellarmate/.var/app/org.kde.kstars/data/kstars/HIPS|' /home/stellarmate/.var/app/org.kde.kstars/config/kstarsrc
 
 # Reset boot to default settings
 echo "Resetting boot to default..."
@@ -26,10 +21,6 @@ cp /etc/stellarmate/boot/* /boot/
 rm -f /boot/.firmware_revision || true
 rm -rf /boot.bak || true
 
-# Enable RustDesk password change service
-echo "Enabling RustDesk password change service..."
-sudo -u stellarmate systemctl --user enable rustdesk-pass-change.service
-
 # Enable filesystem resize service
 echo "Enabling resize file system service..."
 systemctl enable resize-fs.service
